@@ -300,7 +300,7 @@ __vte_pty_merge_environ (char **envp,
 	array = g_ptr_array_sized_new (g_hash_table_size (table) + 1);
         g_hash_table_iter_init(&iter, table);
         while (g_hash_table_iter_next(&iter, (void**) &name, (void**) &value)) {
-                g_ptr_array_add (array, g_strconcat (name, "=", value, NULL));
+                g_ptr_array_add (array, g_strconcat (name, "=", value, nullptr));
         }
         g_assert(g_hash_table_size(table) == array->len);
 	g_hash_table_destroy (table);
